@@ -13,10 +13,14 @@ from .analysis import (
     visualize_numerical_boxplots,
     handle_outliers_median,
     visualize_interactive_boxplots,
-    visualize_heatmap
+    visualize_heatmap,
+    visualize_histograms,
+    visualize_scatter_matrix,
+    visualize_image_classes,
+    assess_image_quality
 )
 
-__version__ = "0.5.1"
+__version__ = "0.10.0"
 __author__ = "Evan Low"
 __email__ = "evan.low@illumetechnology.com"
 
@@ -47,5 +51,10 @@ __all__ = [
     'impute_categorical_mode',
     'visualize_numerical_boxplots',
     'handle_outliers_median',
-    'visualize_interactive_boxplots'
+    'visualize_interactive_boxplots',
+    'visualize_heatmap',
+    'visualize_histograms',
+    'visualize_scatter_matrix',
+    'visualize_image_classes',
+    'assess_image_quality'
 ]
